==> kxdocker_0.39.orig.tar.gz: kxdocker-0.39/src/kxdocker_setup_sources.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Stefano                                         *
 *   stefano@xiaprojects.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
// 0.33
#define KXDOCKERVERSION		"Snapshot_0.0.39"
#define KXDOCKERNEED		"0.0.14"
#define KXDOCKERDATE		"20051001"
#define KXDOCKERHEADERVERSION	"0.0.39"

// 0.37 Gnome support
// 0.37 KDE support
#define USE_KWIN

 
// by default 0.26 support threading
// to enable GPipe plugin 15Gen2005
// #define QT_THREAD_SUPPORT

// enable interpolation engine
#define ENABLE_SPECIALENGINE2

// enable exit by X axis
#define ENABLE_SPECIALENGINE3

// diable HUGE CACHE
#define DISABLE_HUGE_CACHE

// this will disable debug messages and a lot of tests!!!
#define ENABLE_FINAL

// Enable counters and gui statistics, it's a good choice to let's docker know you
#define ENABLE_STATS


// Enable fork to background
#define DAEMON

==> kxdocker_1.1.4a.orig.tar.gz: kxdocker-1.1.4a/src/kxdocker_setup_sources.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Stefano                                         *
 *   stefano@xiaprojects.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

/*--HEADERSTART--*/

// 0.33
#define KXDOCKERVERSION		"1.1.4a"
#define KXDOCKERNEED		"0.0.16"
#define KXDOCKERDATE		"20060417"
#define KXDOCKERHEADERVERSION	"1.0.0"

// 0.37 Gnome support
// 0.37 KDE support
#define USE_KWIN

 
// by default 0.26 support threading
// to enable GPipe plugin 15Gen2005
// #define QT_THREAD_SUPPORT

// enable interpolation engine
#define ENABLE_SPECIALENGINE2

// enable exit by X axis
#define ENABLE_SPECIALENGINE3

// diable HUGE CACHE
#define DISABLE_HUGE_CACHE

// this will disable debug messages and a lot of tests!!!
#define ENABLE_FINAL

// Enable counters and gui statistics, it's a good choice to let's docker know you
#define ENABLE_STATS


// Enable fork to background
#define DAEMON

#define PILLOWMAXHEIGHT 60


/*--HEADERSTOP--*/
